@@ -12,21 +12,23 @@
 # CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations under the License.
 
-import functools
-import json
-import math
-import operator
 import os
-import time
-import stat
-import sys
+import json
 import threading
+import sys
 import traceback
-
-from obs import const, progress, util
-from obs.ilog import DEBUG, ERROR, INFO, WARNING
-from obs.model import BaseModel, CompleteMultipartUploadRequest, CompletePart, GetObjectHeader, GetObjectRequest, \
-    UploadFileHeader
+import functools
+import operator
+from obs import util
+from obs import const
+from obs import progress
+from obs.model import BaseModel
+from obs.model import CompletePart
+from obs.model import CompleteMultipartUploadRequest
+from obs.model import GetObjectRequest
+from obs.model import GetObjectHeader
+from obs.model import UploadFileHeader
+from obs.ilog import INFO, ERROR, DEBUG
 
 if const.IS_PYTHON2:
     import Queue as queue
@@ -34,41 +36,31 @@ else:
     import queue
 
 
-def _resume_upload(bucketName, objectKey, uploadFile, partSize, taskNum, enableCheckPoint, checkPointFile, checkSum,
-                   metadata, progressCallback, obsClient, headers, extensionHeaders=None, encoding_type=None,
-                   isAttachCrc64=False):
+def _resumer_upload(bucketName, objectKey, uploadFile, partSize, taskNum, enableCheckPoint, checkPointFile, checkSum,
+                    metadata, progressCallback, obsClient, headers, extensionHeaders=None):
     upload_operation = uploadOperation(util.to_string(bucketName), util.to_string(objectKey),
                                        util.to_string(uploadFile), partSize, taskNum, enableCheckPoint,
                                        util.to_string(checkPointFile), checkSum, metadata, progressCallback, obsClient,
-                                       headers, extensionHeaders=extensionHeaders, encoding_type=encoding_type,
-                                       isAttachCrc64=isAttachCrc64)
+                                       headers, extensionHeaders=extensionHeaders)
     return upload_operation._upload()
 
 
-def _resume_download(bucketName, objectKey, downloadFile, partSize, taskNum, enableCheckPoint, checkPointFile,
-                     header, versionId, progressCallback, obsClient, imageProcess=None,
-                     notifier=progress.NONE_NOTIFIER, isAttachCrc64=False, extensionHeaders=None):
+def _resumer_download(bucketName, objectKey, downloadFile, partSize, taskNum, enableCheckPoint, checkPointFile,
+                      header, versionId, progressCallback, obsClient, imageProcess=None,
+                      notifier=progress.NONE_NOTIFIER, extensionHeaders=None):
     down_operation = downloadOperation(util.to_string(bucketName), util.to_string(objectKey),
                                        util.to_string(downloadFile), partSize, taskNum, enableCheckPoint,
                                        util.to_string(checkPointFile),
                                        header, versionId, progressCallback, obsClient, imageProcess, notifier,
-                                       isAttachCrc64, extensionHeaders=extensionHeaders)
-
-    return _resume_download_with_operation(down_operation)
-
-
-def _resume_download_with_operation(down_operation):
+                                       extensionHeaders=extensionHeaders)
     if down_operation.size == 0:
         down_operation._delete_record()
         down_operation._delete_tmp_file()
-
-        modes = stat.S_IWUSR | stat.S_IRUSR
-        flags = os.O_RDWR | os.O_TRUNC | os.O_CREAT
-        with os.fdopen(os.open(down_operation.fileName, flags, modes), 'wb'):
+        with open(down_operation.fileName, 'wb'):
             pass
         if down_operation.progressCallback is not None and callable(down_operation.progressCallback):
             down_operation.progressCallback(0, 0, 0)
-        return down_operation._metadata_resp
+        return down_operation._metedata_resp
     return down_operation._download()
 
 
@@ -119,9 +111,7 @@ class Operation(object):
                                           'delete checkpoint file success. path is:{0}'.format(self.checkPointFile))
 
     def _write_record(self, record):
-        modes = stat.S_IWUSR | stat.S_IRUSR
-        flags = os.O_RDWR | os.O_TRUNC | os.O_CREAT
-        with os.fdopen(os.open(self.checkPointFile, flags, modes), 'w') as f:
+        with open(self.checkPointFile, 'w') as f:
             json.dump(record, f)
             self.obsClient.log_client.log(INFO,
                                           'write checkpoint file success. file path is {0}'.format(self.checkPointFile))
@@ -129,18 +119,13 @@ class Operation(object):
 
 class uploadOperation(Operation):
     def __init__(self, bucketName, objectKey, uploadFile, partSize, taskNum, enableCheckPoint, checkPointFile,
-                 checkSum, metadata, progressCallback, obsClient, headers, extensionHeaders=None, encoding_type=None,
-                 isAttachCrc64=False):
-        if enableCheckPoint and not checkPointFile:
-            checkPointFile = uploadFile + '.upload_record'
+                 checkSum, metadata, progressCallback, obsClient, headers, extensionHeaders=None):
         super(uploadOperation, self).__init__(bucketName, objectKey, uploadFile, partSize, taskNum, enableCheckPoint,
                                               checkPointFile, progressCallback, obsClient)
         self.checkSum = checkSum
         self.metadata = metadata
         self.headers = headers
         self.extensionHeaders = extensionHeaders
-        self.encoding_type = encoding_type
-        self.isAttachCrc64 = isAttachCrc64
 
         try:
             self.size = os.path.getsize(self.fileName)
@@ -150,55 +135,24 @@ class uploadOperation(Operation):
             self.obsClient.log_client.log(ERROR,
                                           'something is happened when obtain uploadFile information. Please check')
             raise e
-        self.total_parts = 0
-        self.reset_partSize()
-        self._record = {'bucketName': self.bucketName, 'objectKey': self.objectKey, 'uploadFile': self.fileName,
-                        'partEtags': []}
         resp = self.obsClient.headBucket(self.bucketName, extensionHeaders=extensionHeaders)
         if resp.status > 300:
             raise Exception('head bucket {0} failed. Please check. Status:{1}.'.format(self.bucketName, resp.status))
 
-    def reset_partSize(self):
-        if self.partSize < const.DEFAULT_MINIMUM_SIZE:
-            self.partSize = const.DEFAULT_MINIMUM_SIZE
-        elif self.partSize > const.DEFAULT_MAXIMUM_SIZE:
-            self.partSize = const.DEFAULT_MAXIMUM_SIZE
-        else:
-            self.partSize = util.to_int(self.partSize)
-        if self.taskNum <= 0:
-            self.taskNum = 1
-        else:
-            self.taskNum = int(math.ceil(self.taskNum))
-            try:
-                self.total_parts = int(self.size / self.partSize)
-            except ZeroDivisionError:
-                print("You can't divide by 0!")
-        if self.total_parts >= 10000:
-            self.partSize = int(self.size / 10000) if self.size % 10000 == 0 else int(self.size / 10000) + 1
-            try:
-                self.total_parts = int(self.size / self.partSize)
-            except ZeroDivisionError:
-                print("You can't divide by 0!")
-        if self.size % self.partSize != 0:
-            self.total_parts += 1
-
     def _upload(self):
-        if self.headers is None:
-            self.headers = UploadFileHeader()
-
         if self.enableCheckPoint:
             self._load()
 
-        if "uploadId" not in self._record:
+        if self._record is None:
             self._prepare()
 
         unfinished_upload_parts = []
-        sent_bytes = const.LONG(0)
+        sendedBytes = const.LONG(0)
         for p in self._record['uploadParts']:
             if not p['isCompleted']:
                 unfinished_upload_parts.append(p)
             else:
-                sent_bytes += p['length']
+                sendedBytes += p['length']
 
         if self.progressCallback is not None:
             self.notifier = progress.ProgressNotifier(self.progressCallback, self.size)
@@ -207,8 +161,8 @@ class uploadOperation(Operation):
         try:
             if len(unfinished_upload_parts) > 0:
 
-                if (self.size - sent_bytes) > 0:
-                    self.notifier.send(sent_bytes)
+                if (self.size - sendedBytes) > 0:
+                    self.notifier.send(sendedBytes)
 
                 thread_pools = _ThreadPool(functools.partial(self._produce, upload_parts=unfinished_upload_parts),
                                            [self._consume] * self.taskNum)
@@ -219,7 +173,7 @@ class uploadOperation(Operation):
                                                         extensionHeaders=self.extensionHeaders)
                     self.obsClient.log_client.log(
                         ERROR,
-                        'the code from server is 4**, please check space, permission and so on.'
+                        'the code from server is 4**, please check space、persimission and so on.'
                     )
                     self._delete_record()
                     if self._exception is not None:
@@ -234,18 +188,12 @@ class uploadOperation(Operation):
                         raise Exception('some parts are failed when upload. Please try again')
 
             part_Etags = []
-            if self.isAttachCrc64:
-                for part in self._record['partEtags']:
-                    part_Etags.append(CompletePart(partNum=part['partNum'], etag=part['etag'], crc64=part['crc64'], size=part['size']))
-            else:
-                for part in self._record['partEtags']:
-                    part_Etags.append(CompletePart(partNum=part['partNum'], etag=part['etag']))
-            self.obsClient.log_client.log(INFO, 'Completing to upload multi_parts')
+            for part in self._record['partEtags']:
+                part_Etags.append(CompletePart(partNum=part['partNum'], etag=part['etag']))
+                self.obsClient.log_client.log(INFO, 'Completing to upload multiparts')
             resp = self.obsClient.completeMultipartUpload(self.bucketName, self.objectKey, self._record['uploadId'],
                                                           CompleteMultipartUploadRequest(part_Etags),
-                                                          extensionHeaders=self.extensionHeaders,
-                                                          encoding_type=self.encoding_type,
-                                                          isAttachCrc64=self.isAttachCrc64)
+                                                          extensionHeaders=self.extensionHeaders)
             self._upload_handle_response(resp)
             return resp
         finally:
@@ -282,9 +230,6 @@ class uploadOperation(Operation):
             self.obsClient.log_client.log(ERROR, 'checkpointFile is invalid')
             self._delete_record()
             self._record = None
-        if self._record is None:
-            self._record = {'bucketName': self.bucketName, 'objectKey': self.objectKey, 'uploadFile': self.fileName,
-                            'partEtags': []}
 
     def _type_check(self, record):
         try:
@@ -328,7 +273,7 @@ class uploadOperation(Operation):
             return False
         if self.checkSum and len(record['fileStatus']) >= 3:
             checkSum = util.base64_encode(
-                util.sha256_file_encode_by_size_offset(file_path=self.fileName, size=self.size, offset=0))
+                util.md5_file_encode_by_size_offset(file_path=self.fileName, size=self.size, offset=0))
             if record['fileStatus'][2] and record['fileStatus'][2] != checkSum:
                 self.obsClient.log_client.log(INFO, '{0} content was changed, clear the record.'.format(self.fileName))
                 return False
@@ -336,53 +281,56 @@ class uploadOperation(Operation):
 
     def _slice_file(self):
         uploadParts = []
+        num_counts = int(self.size / self.partSize)
+        if num_counts >= 10000:
+            self.partSize = int(self.size / 10000) if self.size % 10000 == 0 else int(self.size / 10000) + 1
+            num_counts = int(self.size / self.partSize)
+        if self.size % self.partSize != 0:
+            num_counts += 1
 
-        if self.total_parts == 0:
+        if num_counts == 0:
             part = Part(util.to_long(1), util.to_long(0), util.to_long(0), False)
             uploadParts.append(part)
         else:
             offset = 0
-            for i in range(1, self.total_parts + 1, 1):
+            for i in range(1, num_counts + 1, 1):
                 part = Part(util.to_long(i), util.to_long(offset), util.to_long(self.partSize), False)
                 offset += self.partSize
                 uploadParts.append(part)
 
             if self.size % self.partSize != 0:
-                uploadParts[self.total_parts - 1].length = util.to_long(self.size % self.partSize)
+                uploadParts[num_counts - 1].length = util.to_long(self.size % self.partSize)
 
         return uploadParts
 
-    def get_init_upload_result(self):
-        return self.obsClient.initiateMultipartUpload(self.bucketName, self.objectKey, metadata=self.metadata,
+    def _prepare(self):
+        fileStatus = [self.size, self.lastModified]
+        if self.checkSum:
+            fileStatus.append(util.base64_encode(util.md5_file_encode_by_size_offset(self.fileName, self.size, 0)))
+
+        if self.headers is None:
+            self.headers = UploadFileHeader()
+
+        resp = self.obsClient.initiateMultipartUpload(self.bucketName, self.objectKey, metadata=self.metadata,
                                                       acl=self.headers.acl,
                                                       storageClass=self.headers.storageClass,
                                                       websiteRedirectLocation=self.headers.websiteRedirectLocation,
                                                       contentType=self.headers.contentType,
                                                       sseHeader=self.headers.sseHeader, expires=self.headers.expires,
                                                       extensionGrants=self.headers.extensionGrants,
-                                                      extensionHeaders=self.extensionHeaders,
-                                                      encoding_type=self.encoding_type)
-
-    def _prepare(self):
-        fileStatus = [self.size, self.lastModified]
-        if self.checkSum:
-            fileStatus.append(util.base64_encode(util.sha256_file_encode_by_size_offset(self.fileName, self.size, 0)))
-
-        resp = self.get_init_upload_result()
-
+                                                      extensionHeaders=self.extensionHeaders)
         if resp.status > 300:
             raise Exception('initiateMultipartUpload failed. ErrorCode:{0}. ErrorMessage:{1}'.format(resp.errorCode,
                                                                                                      resp.errorMessage))
         uploadId = resp.body.uploadId
-        self._record["uploadParts"] = self._slice_file()
-        self._record["uploadId"] = uploadId
-        self._record["fileStatus"] = fileStatus
+        self._record = {'bucketName': self.bucketName, 'objectKey': self.objectKey, 'uploadId': uploadId,
+                        'uploadFile': self.fileName, 'fileStatus': fileStatus, 'uploadParts': self._slice_file(),
+                        'partEtags': []}
         self.obsClient.log_client.log(INFO, 'prepare new upload task success. uploadId = {0}'.format(uploadId))
         if self.enableCheckPoint:
             self._write_record(self._record)
 
-    @staticmethod
-    def _produce(ThreadPool, upload_parts):
+    def _produce(self, ThreadPool, upload_parts):
         for part in upload_parts:
             ThreadPool.put(part)
 
@@ -396,10 +344,15 @@ class uploadOperation(Operation):
     def _upload_part(self, part):
         if not self._is_abort():
             try:
-                resp = self.get_upload_part_resp(part)
+                resp = self.obsClient._uploadPartWithNotifier(self.bucketName, self.objectKey, part['partNumber'],
+                                                              self._record['uploadId'], self.fileName,
+                                                              isFile=True, partSize=part['length'],
+                                                              offset=part['offset'], notifier=self.notifier,
+                                                              extensionHeaders=self.extensionHeaders,
+                                                              sseHeader=self.headers.sseHeader)
                 if resp.status < 300:
                     self._record['uploadParts'][part['partNumber'] - 1]['isCompleted'] = True
-                    self._record['partEtags'].append(CompletePart(util.to_int(part['partNumber']), resp.body.etag, resp.body.crc64, util.to_int(part['length'])))
+                    self._record['partEtags'].append(CompletePart(util.to_int(part['partNumber']), resp.body.etag))
                     if self.enableCheckPoint:
                         with self._lock:
                             self._write_record(self._record)
@@ -414,21 +367,11 @@ class uploadOperation(Operation):
                 self.obsClient.log_client.log(DEBUG, 'upload part %s error, %s' % (part['partNumber'], e))
                 self.obsClient.log_client.log(ERROR, traceback.format_exc())
 
-    def get_upload_part_resp(self, part):
-        return self.obsClient._uploadPartWithNotifier(self.bucketName, self.objectKey, part['partNumber'],
-                                                      self._record['uploadId'], self.fileName,
-                                                      isFile=True, partSize=part['length'],
-                                                      offset=part['offset'], notifier=self.notifier,
-                                                      extensionHeaders=self.extensionHeaders,
-                                                      sseHeader=self.headers.sseHeader, isAttachCrc64=self.isAttachCrc64)
-
 
 class downloadOperation(Operation):
     def __init__(self, bucketName, objectKey, downloadFile, partSize, taskNum, enableCheckPoint, checkPointFile,
                  header, versionId, progressCallback, obsClient, imageProcess=None, notifier=progress.NONE_NOTIFIER,
-                 isAttachCrc64=False, extensionHeaders=None):
-        if enableCheckPoint and not checkPointFile:
-            checkPointFile = downloadFile + '.download_record'
+                 extensionHeaders=None):
         super(downloadOperation, self).__init__(bucketName, objectKey, downloadFile, partSize, taskNum,
                                                 enableCheckPoint,
                                                 checkPointFile, progressCallback, obsClient, notifier)
@@ -436,39 +379,32 @@ class downloadOperation(Operation):
         self.versionId = versionId
         self.imageProcess = imageProcess
         self.extensionHeaders = extensionHeaders
-        self.isAttachCrc64 = isAttachCrc64
-        self._record = {'bucketName': self.bucketName, 'objectKey': self.objectKey, 'versionId': self.versionId,
-                        'downloadFile': self.fileName, 'imageProcess': self.imageProcess}
 
         parent_dir = os.path.dirname(self.fileName)
         if not os.path.exists(parent_dir):
             os.makedirs(parent_dir)
 
         self._tmp_file = self.fileName + '.tmp'
-        metadata_resp = self.obsClient.getObjectMetadata(self.bucketName, self.objectKey, self.versionId,
+        metedata_resp = self.obsClient.getObjectMetadata(self.bucketName, self.objectKey, self.versionId,
                                                          extensionHeaders=self.extensionHeaders,
                                                          sseHeader=self.header.sseHeader, origin=self.header.origin,
                                                          requestHeaders=self.header.requestHeaders)
-        if metadata_resp.status < 300:
-            self.lastModified = metadata_resp.body.lastModified
-            self.crc64 = metadata_resp.body.crc64
-            if self.isAttachCrc64 and not self.crc64:
-                self.obsClient.log_client.log(WARNING,
-                                              'object {0} not get CRC64 from the server.'.format(self.objectKey))
-            self.size = metadata_resp.body.contentLength \
-                if metadata_resp.body.contentLength is not None and metadata_resp.body.contentLength >= 0 else 0
+        if metedata_resp.status < 300:
+            self.lastModified = metedata_resp.body.lastModified
+            self.size = metedata_resp.body.contentLength \
+                if metedata_resp.body.contentLength is not None and metedata_resp.body.contentLength >= 0 else 0
         else:
-            if 400 <= metadata_resp.status < 500:
+            if 400 <= metedata_resp.status < 500:
                 self._delete_record()
                 self._delete_tmp_file()
             self.obsClient.log_client.log(
                 ERROR,
-                'there are something wrong when touch the object {0}. ErrorCode:{1}, ErrorMessage:{2}'.format(
-                    self.objectKey, metadata_resp.errorCode, metadata_resp.errorMessage))
+                'there are something wrong when touch the objetc {0}. ErrorCode:{1}, ErrorMessage:{2}'.format(
+                    self.objectKey, metedata_resp.errorCode, metedata_resp.errorMessage))
             raise Exception(
-                'there are something wrong when touch the object {0}. ErrorCode:{1}, ErrorMessage:{2}'.format(
-                    self.objectKey, metadata_resp.status, metadata_resp.errorMessage))
-        self._metadata_resp = metadata_resp
+                'there are something wrong when touch the objetc {0}. ErrorCode:{1}, ErrorMessage:{2}'.format(
+                    self.objectKey, metedata_resp.status, metedata_resp.errorMessage))
+        self._metedata_resp = metedata_resp
 
     def _delete_tmp_file(self):
         if os.path.exists(self._tmp_file):
@@ -476,12 +412,10 @@ class downloadOperation(Operation):
 
     def _do_rename(self):
         try:
-            modes = stat.S_IWUSR | stat.S_IRUSR
-            flags = os.O_RDWR | os.O_TRUNC | os.O_CREAT
-            with os.fdopen(os.open(self.fileName, flags, modes), 'wb') as wf:
+            with open(self.fileName, 'wb') as wf:
                 with open(self._tmp_file, 'rb') as rf:
                     while True:
-                        chunk = rf.read(const.READ_ONCE_LENGTH)
+                        chunk = rf.read(65536)
                         if not chunk:
                             break
                         wf.write(chunk)
@@ -498,19 +432,19 @@ class downloadOperation(Operation):
         if self.enableCheckPoint:
             self._load()
 
-        if "downloadParts" not in self._record:
+        if not self._record:
             self._prepare()
 
-        sent_bytes, unfinished_down_parts = self._download_prepare()
+        sendedBytes, unfinished_down_parts = self._download_prepare()
 
         try:
             if len(unfinished_down_parts) > 0:
-                if (self.size - sent_bytes) > 0:
+                if (self.size - sendedBytes) > 0:
                     if self.progressCallback is not None:
                         self.notifier = progress.ProgressNotifier(self.progressCallback, self.size)
                         inner_notifier = True
                         self.notifier.start()
-                    self.notifier.send(sent_bytes)
+                    self.notifier.send(sendedBytes)
 
                 thread_pools = _ThreadPool(functools.partial(self._produce, download_parts=unfinished_down_parts),
                                            [self._consume] * self.taskNum)
@@ -526,52 +460,35 @@ class downloadOperation(Operation):
                     if not p['isCompleted']:
                         raise Exception('some parts are failed when download. Please try again')
 
-            if self.isAttachCrc64 and self.crc64:
-                self.obsClient.log_client.log(
-                    INFO,
-                    'Start to calculate file {0} crc64'.format(self.fileName))
-                start = time.time()
-                crc64 = util.calculate_file_crc64(self._tmp_file)
-                self.obsClient.log_client.log(
-                    DEBUG,
-                    'CRC64 from the server is {0}, CRC64 by calculated is {1}, cost {2}'.format(self.crc64, crc64, time.time()-start))
-                if int(self.crc64) != crc64:
-                    self._delete_record()
-                    self._delete_tmp_file()
-                    raise Exception(
-                        'Consistency check failed. CRC64 from the server is {0}, CRC64 by calculated is {1}'.format(
-                            int(self.crc64), crc64))
             try:
                 os.rename(self._tmp_file, self.fileName)
                 if self.enableCheckPoint:
                     self._delete_record()
                 self.obsClient.log_client.log(INFO, 'download success.')
-                return self._metadata_resp
+                return self._metedata_resp
             except Exception as e:
                 if self._do_rename():
                     self.obsClient.log_client.log(INFO, 'download success.')
-                    return self._metadata_resp
+                    return self._metedata_resp
                 if not self.enableCheckPoint:
                     self._delete_tmp_file()
                 self.obsClient.log_client.log(
                     INFO,
                     'Rename failed. The reason maybe:[the {0} exists, not a file path, not permission]. Please check.')
                 raise e
-        except Exception as e:
-            raise e
         finally:
             if inner_notifier:
                 self.notifier.end()
 
     def _download_prepare(self):
-        sent_bytes = 0
+        sendedBytes = 0
         unfinished_down_parts = []
         for part in self._record['downloadParts']:
             if not part['isCompleted']:
                 unfinished_down_parts.append(part)
             else:
-                sent_bytes += (part['length'] - part['offset']) + 1
-        return sent_bytes, unfinished_down_parts
+                sendedBytes += (part['length'] - part['offset']) + 1
+        return sendedBytes, unfinished_down_parts
 
     def _load(self):
         self._record = self._get_record()
@@ -580,23 +497,19 @@ class downloadOperation(Operation):
             self._delete_record()
             self._delete_tmp_file()
             self._record = None
-        if self._record is None:
-            self._record = {'bucketName': self.bucketName, 'objectKey': self.objectKey, 'versionId': self.versionId,
-                            'downloadFile': self.fileName, 'imageProcess': self.imageProcess}
 
     def _prepare(self):
-        object_status = [self.objectKey, self.size, self.lastModified, self.versionId, self.imageProcess]
-        modes = stat.S_IWUSR | stat.S_IRUSR
-        flags = os.O_RDWR | os.O_TRUNC | os.O_CREAT
-        with os.fdopen(os.open(_to_unicode(self._tmp_file), flags, modes), 'wb') as f:
+        object_staus = [self.objectKey, self.size, self.lastModified, self.versionId, self.imageProcess]
+        with open(_to_unicode(self._tmp_file), 'wb') as f:
             if self.size > 0:
                 f.seek(self.size - 1, 0)
             f.write('b' if const.IS_PYTHON2 else 'b'.encode('UTF-8'))
 
         tmp_file_status = [os.path.getsize(self._tmp_file), os.path.getmtime(self._tmp_file)]
-        self._record["downloadParts"] = self._split_object()
-        self._record["objectStatus"] = object_status
-        self._record["tmpFileStatus"] = tmp_file_status
+        self._record = {'bucketName': self.bucketName, 'objectKey': self.objectKey, 'versionId': self.versionId,
+                        'downloadFile': self.fileName, 'downloadParts': self._split_object(),
+                        'objectStatus': object_staus,
+                        'tmpFileStatus': tmp_file_status, 'imageProcess': self.imageProcess}
         self.obsClient.log_client.log(INFO, 'prepare new download task success.')
         if self.enableCheckPoint:
             self._write_record(self._record)
@@ -645,16 +558,10 @@ class downloadOperation(Operation):
 
     def _split_object(self):
         downloadParts = []
-        try:
-            num_counts = int(self.size / self.partSize)
-        except ZeroDivisionError:
-            print("You can't divide by 0!")
+        num_counts = int(self.size / self.partSize)
         if num_counts >= 10000:
             self.partSize = int(self.size / 10000) if self.size % 10000 == 0 else int(self.size / 10000) + 1
-            try:
-                num_counts = int(self.size / self.partSize)
-            except ZeroDivisionError:
-                print("You can't divide by 0!")
+            num_counts = int(self.size / self.partSize)
         if self.size % self.partSize != 0:
             num_counts += 1
         start = 0
@@ -665,8 +572,7 @@ class downloadOperation(Operation):
             downloadParts.append(part)
         return downloadParts
 
-    @staticmethod
-    def _produce(ThreadPool, download_parts):
+    def _produce(self, ThreadPool, download_parts):
         for part in download_parts:
             ThreadPool.put(part)
 
@@ -677,8 +583,7 @@ class downloadOperation(Operation):
                 break
             self._download_part(part)
 
-    @staticmethod
-    def _copy_get_object_header(src_header):
+    def _copy_get_object_header(self, src_header):
         get_object_header = GetObjectHeader()
         get_object_header.sseHeader = src_header.sseHeader
         get_object_header.if_match = src_header.if_match
@@ -692,16 +597,15 @@ class downloadOperation(Operation):
         get_object_header = self._copy_get_object_header(self.header)
         get_object_header.range = util.to_string(part['offset']) + '-' + util.to_string(part['length'])
         if not self._is_abort():
-            # todo 检视 response 的作用与 part_response 的重构
             response = None
             try:
-                resp = self.obsClient.getObject(bucketName=self.bucketName, objectKey=self.objectKey,
-                                                getObjectRequest=get_object_request,
-                                                headers=get_object_header, notifier=self.notifier,
-                                                extensionHeaders=self.extensionHeaders)
+                resp = self.obsClient._getObjectWithNotifier(bucketName=self.bucketName, objectKey=self.objectKey,
+                                                             getObjectRequest=get_object_request,
+                                                             headers=get_object_header, notifier=self.notifier,
+                                                             extensionHeaders=self.extensionHeaders)
                 if resp.status < 300:
-                    part_response = resp.body.response
-                    self._download_part_write(part_response, part)
+                    respone = resp.body.response
+                    self._download_part_write(respone, part)
                     self._record['downloadParts'][part['partNumber'] - 1]['isCompleted'] = True
                     if self.enableCheckPoint:
                         with self._lock:
@@ -721,15 +625,15 @@ class downloadOperation(Operation):
                 self.obsClient.log_client.log(ERROR, traceback.format_exc())
             finally:
                 if response is not None:
-                    part_response.close()
+                    respone.close()
 
-    def _download_part_write(self, response, part):
-        chunk_size = const.READ_ONCE_LENGTH
-        if response is not None:
+    def _download_part_write(self, respone, part):
+        chunk_size = 65536
+        if respone is not None:
             with open(_to_unicode(self._tmp_file), 'rb+') as fs:
                 fs.seek(part['offset'], 0)
                 while True:
-                    chunk = response.read(chunk_size)
+                    chunk = respone.read(chunk_size)
                     if not chunk:
                         break
                     fs.write(chunk)
@@ -800,8 +704,7 @@ class _ThreadPool(object):
         with self._lock:
             return self._exc_info is None
 
-    @staticmethod
-    def _add_and_run(thread, pool):
+    def _add_and_run(self, thread, pool):
         thread.daemon = True
         thread.start()
         pool.append(thread)
